@@ -13,7 +13,7 @@
 #include "fitsioutils.h"
 #include "fitsfile.h"
 #include "ioutils.h"
-#include "an-endian.h"
+//#include "an-endian.h" //# Modified by Robert Lancaster for the StellarSolver Internal Library
 #include "anqfits.h"
 
 #include "log.h"
@@ -52,11 +52,11 @@ struct fitsext {
 typedef struct fitsext fitsext_t;
 
 
-
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
 static anbool need_endian_flip() {
     return IS_BIG_ENDIAN == 0;
 }
-
+**/
 //static void fitstable_add_columns(fitstable_t* tab, fitscol_t* cols, int Ncols);
 static fitscol_t* fitstable_add_column(fitstable_t* tab, fitscol_t* col);
 static void fitstable_create_table(fitstable_t* tab);
@@ -233,7 +233,7 @@ int fitstable_read_nrows_data(fitstable_t* table, int row0, int nrows,
     }
     return 0;
 }
-
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
 void fitstable_endian_flip_row_data(fitstable_t* table, void* data) {
     int i;
     char* cursor;
@@ -244,23 +244,23 @@ void fitstable_endian_flip_row_data(fitstable_t* table, void* data) {
         int j;
         fitscol_t* col = getcol(table, i);
         for (j=0; j<col->arraysize; j++) {
-            /*
+
              if (col->fitssize == 8)
              printf("col '%s': d=%g, i=%li\n",
              col->colname, *((double*)cursor), *((uint64_t*)cursor));
-             */
-            endian_swap(cursor, col->fitssize);
-            /*
+
+            //endian_swap(cursor, col->fitssize); //# Modified by Robert Lancaster for the StellarSolver Internal Library
+
              if (col->fitssize == 8)
              printf(" --> d=%g, i=%li\n",
              *((double*)cursor), *((uint64_t*)cursor));
-             */
+
 
             cursor += col->fitssize;
         }
     }
 }
-
+**/
 static int write_row_data(fitstable_t* table, void* data, int R) {
     assert(table);
     assert(data);
@@ -291,7 +291,7 @@ int fitstable_copy_rows_data(fitstable_t* intable, int* rows, int N, fitstable_t
     char* buf = NULL;
     int i;
     // We need to endian-flip if we're going from FITS file <--> memory.
-    anbool flip = need_endian_flip() && (in_memory(intable) != in_memory(outtable));
+    //anbool flip = need_endian_flip() && (in_memory(intable) != in_memory(outtable)); //# Modified by Robert Lancaster for the StellarSolver Internal Library
     R = fitstable_row_size(intable);
     buf = malloc(R);
     for (i=0; i<N; i++) {
@@ -301,12 +301,14 @@ int fitstable_copy_rows_data(fitstable_t* intable, int* rows, int N, fitstable_t
             return -1;
         }
         // The in-memory side (input/output) does the flip.
+        /** //# Modified by Robert Lancaster for the StellarSolver Internal Library
         if (flip) {
             if (in_memory(intable))
                 fitstable_endian_flip_row_data(intable, buf);
             else if (in_memory(outtable))
                 fitstable_endian_flip_row_data(outtable, buf);
         }
+        **/
 
         if (write_row_data(outtable, buf, R)) {
             ERROR("Failed to write data to output table");
@@ -317,11 +319,11 @@ int fitstable_copy_rows_data(fitstable_t* intable, int* rows, int N, fitstable_t
     free(buf);
     return 0;
 }
-
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
 int fitstable_copy_row_data(fitstable_t* table, int row, fitstable_t* outtable) {
     return fitstable_copy_rows_data(table, &row, 1, outtable);
 }
-
+**/
 int fitstable_row_size(const fitstable_t* t) {
     // FIXME - should this return the size of the *existing* FITS table
     // (when reading), or just the columns we care about (those in "cols")?
@@ -653,9 +655,10 @@ int fitstable_read_structs(fitstable_t* tab, void* struc,
             //logverb("column %i: dest offset %i, stride %i, row offset %i, input offset %i, size %i (%ix%i)\n", i, (int)(dest - struc), stride, offset, off, fitscolumn_get_size(col), col->fitssize, col->arraysize);
             sz = fitscolumn_get_size(col);
             for (j=0; j<N; j++)
-                memcpy(((char*)dest) + j * stride,
-                       ((char*)bl_access(tab->rows, offset+j)) + off,
-                       sz);
+                if(dest) //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
+                    memcpy(((char*)dest) + j * stride,
+                           ((char*)bl_access(tab->rows, offset+j)) + off,
+                           sz);
         } else {
             // Read from FITS file...
             qfits_query_column_seq_to_array(tab->table, col->col, offset, N, dest, stride);
@@ -734,16 +737,17 @@ static int write_one(fitstable_t* table, const void* struc, anbool flip,
                               col->arraysize, 1);
             columndata = buf;
         }
-		
-        if (in_memory(table)) {
-            int nb = fitscolumn_get_size(col);
-            memcpy(thisrow + rowoff, columndata, nb);
-            rowoff += nb;
-        } else {
-            ret = fits_write_data_array(table->fid, columndata,
-                                        col->fitstype, col->arraysize, flip);
-            if (ret)
-                break;
+        if(columndata){ //# Modified by Robert Lancaster for the StellarSolver Internal Library to correct warning
+            if (in_memory(table)) {
+                int nb = fitscolumn_get_size(col);
+                memcpy(thisrow + rowoff, columndata, nb);
+                rowoff += nb;
+            } else {
+                ret = fits_write_data_array(table->fid, columndata,
+                                            col->fitstype, col->arraysize, flip);
+                if (ret)
+                    break;
+            }
         }
     }
     free(buf);
@@ -1308,7 +1312,7 @@ int fitstable_append_to(fitstable_t* intable, FILE* fid) {
 
     exit: //# Modified by Robert Lancaster for the StellarSolver Internal Library, to prevent leak
     fitstable_close(outtable);
-    return 0;
+    return status; //# Modified by Robert Lancaster for the StellarSolver Internal Library, to prevent leak
 }
 
 int fitstable_close(fitstable_t* tab) {
@@ -1600,11 +1604,11 @@ int fitstable_nrows(const fitstable_t* t) {
 
 void fitstable_print_missing(fitstable_t* tab, FILE* f) {
     int i;
-    fprintf(f, "Missing required columns: ");
+    debug("Missing required columns: "); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
     for (i=0; i<ncols(tab); i++) {
         fitscol_t* col = getcol(tab, i);
         if (col->col == -1 && col->required) {
-            fprintf(f, "%s ", col->colname);
+            debug("%s ", col->colname); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         }
     }
 }
